@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 ###################
-#    This file test the WebScript.py file
+#    This file tests the WebScript.py file
 #    from the command line and display the result in a web interface.
-#    Copyright (C) 2021  Maurice Lambert
+#    Copyright (C) 2021, 2022  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,9 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This file test the commons.py file"""
+"""
+This file tests the commons.py file
+"""
 
 from unittest.mock import Mock, patch
 from unittest import TestCase, main
@@ -33,7 +35,10 @@ import json
 import sys
 import os
 
-sys.path = [path.join(path.dirname(__file__), ".."), *sys.path]
+WebScripts_path = path.join(path.dirname(__file__), "..")
+
+if WebScripts_path not in sys.path:
+    sys.path.insert(0, WebScripts_path)
 
 from WebScripts.commons import (
     Argument,
